StatefulHookComponent class abstract

A stateful Jaspr component whose State.build method may call hooks.

This is useful when hooks need to coexist with Jaspr state mixins such as PreloadStateMixin or SyncStateMixin.

Constructors

StatefulHookComponent({Key? key})
Creates a stateful hook component.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → Element
Creates a StatefulElement to manage this component's location in the tree.
createState() → State<StatefulComponent>
Creates the mutable state for this component at a given location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited