ClipboardController class abstract interface

Reads and writes plain text through the browser Clipboard API.

Properties

error Object?
The most recent operation error.
no setter
hashCode int
The hash code for this object.
no setterinherited
isSupported bool
Whether the Clipboard API is available in the current browser context.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ClipboardStatus
The current operation status.
no setter
text String?
The most recently read or written text.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readText() Future<String>
Reads plain text from the clipboard.
toString() String
A string representation of this object.
inherited
writeText(String value) Future<void>
Writes value to the clipboard.

Operators

operator ==(Object other) bool
The equality operator.
inherited