ElementSize class final
A measured element size in the units reported for the selected observer box.
- Annotations
-
- @immutable
Constructors
- ElementSize(double width, double height)
-
Creates an element-size value.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override