FocusController class abstract interface

An imperative focus handle returned by useFocus.

Properties

hasFocus bool?
Whether the target currently owns document focus, or null before attachment.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blur() → void
Removes focus from the attached target.
focus({bool preventScroll = false}) → void
Requests focus for the attached target.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited