hasFocus property
bool?
get
hasFocus
Whether the target currently owns document focus, or null before attachment.
Implementation
bool? get hasFocus;
Whether the target currently owns document focus, or null before attachment.
bool? get hasFocus;