Controls and observes the browser's same-document session history.
Properties
- entry → HistoryEntry
-
The current entry.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
back(
) → void - Navigates backward by one entry.
-
forward(
) → void - Navigates forward by one entry.
-
go(
int delta) → void -
Navigates by
deltaentries. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
push(
Uri uri, {Object? state}) → void - Adds a same-document history entry.
-
replace(
Uri uri, {Object? state}) → void - Replaces the current same-document history entry.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited