HistoryEntry class final

The current browser history entry.

Annotations
  • @immutable

Constructors

HistoryEntry({required Uri uri, Object? state})
Creates a history entry snapshot.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Object?
The structured-clone-compatible state associated with the entry.
final
uri Uri
The current document URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override