root property
GlobalNodeKey<Element> ?
root
final
A keyed element used as the intersection root, or null for the viewport.
Implementation
final GlobalNodeKey<web.Element>? root;
A keyed element used as the intersection root, or null for the viewport.
final GlobalNodeKey<web.Element>? root;