IntersectionSnapshot class final

The latest intersection state for a keyed element.

Annotations
  • @immutable

Constructors

IntersectionSnapshot({required bool isIntersecting, required double ratio})
Creates an intersection snapshot.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isIntersecting bool
Whether the target currently intersects its root.
final
ratio double
The visible proportion of the target from zero to one.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override