WebEventListenerOptions class final
Native DOM event-listener options.
- Annotations
-
- @immutable
Constructors
- WebEventListenerOptions({bool capture = false, bool passive = false, bool once = false})
-
Creates event-listener options.
const
Properties
- capture → bool
-
Receives the event during the capture phase.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- once → bool
-
Removes the native listener after its first event.
final
- passive → bool
-
Declares that the listener does not call
preventDefault.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override