WindowSize class final

The browser viewport size in CSS pixels.

Annotations
  • @immutable

Constructors

WindowSize(double width, double height)
Creates a viewport-size value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
height double
The viewport height.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
The viewport width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override