WindowSizeOptions class final

Configuration for viewport-size updates.

Annotations
  • @immutable

Constructors

WindowSizeOptions({Duration? debounce})
Creates viewport-size options.
const

Properties

debounce Duration?
Delays resize updates until browser events have settled.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override