useFocusWithin function
Returns whether focus is on target or one of its descendants.
Implementation
bool? useFocusWithin(GlobalNodeKey<web.Element> target, {bool enabled = true}) {
return use(_FocusWithinHook(target, enabled));
}
Returns whether focus is on target or one of its descendants.
bool? useFocusWithin(GlobalNodeKey<web.Element> target, {bool enabled = true}) {
return use(_FocusWithinHook(target, enabled));
}