MutationObserverOptions class final
Configuration for a DOM mutation observer.
- Annotations
-
- @immutable
Constructors
Properties
-
attributeFilter
→ List<
String> ? -
Limits attribute observation to these names.
final
- attributeOldValue → bool
-
Includes the previous attribute value in mutation records.
final
- attributes → bool
-
Observes attribute changes.
final
- characterData → bool
-
Observes text-node changes.
final
- characterDataOldValue → bool
-
Includes the previous text value in mutation records.
final
- childList → bool
-
Observes direct child additions and removals.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isValid → bool
-
Whether the options observe at least one mutation category.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtree → bool
-
Extends observation to descendants.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override